/*
    See the JupyterLab Developer Guide for useful CSS Patterns:

    https://jupyterlab.readthedocs.io/en/stable/developer/css.html
*/

.onyx-Widget {
  overflow: auto;
}

.table {
  font-family: unset;
}